@@ -2,6 +2,7 @@ library('data.table')
 library('foreach')
 library('qs')
 library('BEDMatrix')
+library('survival')
 registerDoSEQ()
 
 
@@ -20,19 +21,37 @@ icdTest = data.table(
   person_id = c(1, rep(2L, 3), 3, rep(4L, 3)),
   icd = c('001', '002', '003', '005', '002', '004', '005', '006'),
   flag = 9,
-  entry_date = c(
-    rep(as.Date('2000/01/01'), 6),
-    c(as.Date('2000/01/01'), as.Date('2000/01/02'))))
+  occurrence_age = c(rep(10, 6), c(10, 11)))
 
 demosTest = data.table(
-  person_id = 1:4, sex = c('female', 'male', 'female', 'male'))
+  person_id = 1:4,
+  sex = c('female', 'male', 'female', 'male'),
+  first_age = seq(20, 23),
+  last_age = seq(25, 28))
 
 phecodeOccurrencesTest = data.table(
   person_id = c(1, rep(2L, 2), 3, 4),
   phecode = c('001', '002', '003', '002', '004'),
-  entry_date = rep(as.Date('2000/01/01'), 5))
+  occurrence_age = rep(10, 5))
 setkey(phecodeOccurrencesTest)
 
+phecodeOccurrencesLLTest = data.table(
+  person_id = c(1, rep(2L, 2), 3, 4),
+  phecode = c('001', '002', '003', '002', '004'),
+  num_occurrences = rep(1, 5))
+setkey(phecodeOccurrencesLLTest)
+
+phecodeOccurrencesCoxTest = data.table(
+  person_id = c(1, rep(2L, 2), 3, 4),
+  phecode = c('001', '002', '003', '002', '004'),
+  occurrence_age = seq(22, 26))
+setkey(phecodeOccurrencesCoxTest)
+
+phecodeOccurrencesPreCalcTest = data.table(
+  person_id = c(1, rep(2L, 2), 3, 4),
+  phecode = c('700', '200', '300', '200', '500'))
+setkey(phecodeOccurrencesPreCalcTest)
+
 dxIcdTest = data.table(disease_id = 1, icd = c('005', '006'), flag = 9)
 
 diseasePhecodeMapTest = data.table(
